@@ -10,6 +10,7 @@ class PrecursorEnum(Enum):
     JP2O0 = 'jp2o0'
     PRJPG = 'prjpg'
     PNGZO = 'pngzo'
+    JXL0 = 'jxl0'
 
     @staticmethod
     def list():
@@ -22,3 +23,4 @@ class PrecursorToExtensionEnum(Enum):
     JP2O0 = '.jp2'
     PRJPG = '.jpeg'
     PNGZO = '.png'
+    JXL0 = '.jxl'
