@@ -7,6 +7,7 @@ from typing import (
 import hashlib
 import io
 from inspect import isfunction
+import asyncio
 
 from asyncfile import (
     AsyncBufferedReader,
@@ -47,14 +48,19 @@ class OnePassInfo(NamedTuple):
 
 
 async def stream_from_argument(arg: ImageArg) -> Callable:
+    loop = asyncio.get_event_loop()
     def from_file_path() -> AsyncBufferedReader:
         assert isinstance(arg, str)
         wrap = AsyncFileIO(arg, 'rb')
-        return AsyncBufferedReader(wrap, buffer_size=BUF_SIZE)
+        return AsyncBufferedReader(wrap, buffer_size=BUF_SIZE, loop=loop)
 
     def from_bytes() -> AsyncBufferedReader:
         assert isinstance(arg, bytes)
-        return AsyncBufferedReader(io.BytesIO(arg), buffer_size=BUF_SIZE)
+        return AsyncBufferedReader(
+            io.BytesIO(arg),
+            buffer_size=BUF_SIZE,
+            loop=loop
+        )
 
     if isinstance(arg, str):
         # Consider it a filename.
